## dbt-adapters 1.13.1 - January 10, 2025

### Fixes

- Fix is_replaceable check with wrong variable ([#187](https://github.com/dbt-labs/dbt-adapters/issues/187))
- Fix the snapshot merge query for several adapters in new_record mode. ([#385](https://github.com/dbt-labs/dbt-adapters/issues/385))

### Contributors
- [@rongfengliang](https://github.com/rongfengliang) ([#187](https://github.com/dbt-labs/dbt-adapters/issues/187))
